diff --git a/build.gradle b/build.gradle
index 6ec828b..c08f2ba 100644
--- a/build.gradle
+++ b/build.gradle
@@ -38,7 +38,7 @@ dependencies {
compile 'org.ostermiller:utils:1.07.00'
compile 'net.sourceforge.jweather:jweather:0.3.0@jar'
- compile 'de.congrace:exp4j:0.3.11'
+ compile 'net.objecthunter:exp4j:0.4.5'
compile 'org.twitter4j:twitter4j-core:4.0.4'
compile 'net.sf.delicious-java:delicious:1.14'
diff --git a/buildnum.properties b/buildnum.properties
index ec85d8a..268e39c 100644
--- a/buildnum.properties
+++ b/buildnum.properties
@@ -1,3 +1,3 @@
#ANT Task: ch.oscg.jreleaseinfo.BuildNumberHandler
-#Mon Aug 31 12:19:55 PDT 2015
+#Mon Oct 26 14:39:18 PDT 2015
build.num.last=0
diff --git a/gradle/wrapper/gradle-wrapper.jar b/gradle/wrapper/gradle-wrapper.jar
index b5166da..e8c6bf7 100644
Binary files a/gradle/wrapper/gradle-wrapper.jar and b/gradle/wrapper/gradle-wrapper.jar differ
diff --git a/gradle/wrapper/gradle-wrapper.properties b/gradle/wrapper/gradle-wrapper.properties
index 0196fc2..580ff2f 100644
--- a/gradle/wrapper/gradle-wrapper.properties
+++ b/gradle/wrapper/gradle-wrapper.properties
@@ -1,6 +1,6 @@
-#Sat Aug 29 12:01:59 PDT 2015
+#Sat Oct 24 14:24:39 PDT 2015
distributionBase=GRADLE_USER_HOME
distributionPath=wrapper/dists
zipStoreBase=GRADLE_USER_HOME
zipStorePath=wrapper/dists
-distributionUrl=https\://services.gradle.org/distributions/gradle-2.4-bin.zip
+distributionUrl=https\://services.gradle.org/distributions/gradle-2.7-bin.zip
diff --git a/gradlew b/gradlew
index 91a7e26..97fac78 100644
--- a/gradlew
+++ b/gradlew
@@ -42,11 +42,6 @@ case "`uname`" in
;;
esac
-# For Cygwin, ensure paths are in UNIX format before anything is touched.
-if $cygwin ; then
- [ -n "$JAVA_HOME" ] && JAVA_HOME=`cygpath --unix "$JAVA_HOME"`
-fi
-
# Attempt to set APP_HOME
# Resolve links: $0 may be a link
PRG="$0"
@@ -114,6 +109,7 @@ fi
if $cygwin ; then
APP_HOME=`cygpath --path --mixed "$APP_HOME"`
CLASSPATH=`cygpath --path --mixed "$CLASSPATH"`
+ JAVACMD=`cygpath --unix "$JAVACMD"`
# We build the pattern for arguments to be converted via cygpath
ROOTDIRSRAW=`find -L / -maxdepth 1 -mindepth 1 -type d 2>/dev/null`
diff --git a/mobibot.iml b/mobibot.iml
index df170be..de5056b 100644
--- a/mobibot.iml
+++ b/mobibot.iml
@@ -24,7 +24,6 @@
-
@@ -32,5 +31,6 @@
+
\ No newline at end of file
diff --git a/mobibot.ipr b/mobibot.ipr
index d8dbbc2..f85427e 100644
--- a/mobibot.ipr
+++ b/mobibot.ipr
@@ -438,15 +438,6 @@
-
-
-
-
-
-
-
-
-
@@ -456,6 +447,15 @@
+
+
+
+
+
+
+
+
+
diff --git a/src/main/java/net/thauvin/erik/mobibot/Mobibot.java b/src/main/java/net/thauvin/erik/mobibot/Mobibot.java
index 799d71f..5137b08 100644
--- a/src/main/java/net/thauvin/erik/mobibot/Mobibot.java
+++ b/src/main/java/net/thauvin/erik/mobibot/Mobibot.java
@@ -36,8 +36,8 @@ package net.thauvin.erik.mobibot;
import com.sun.syndication.fetcher.impl.FeedFetcherCache;
import com.sun.syndication.fetcher.impl.HashMapFeedInfoCache;
import com.sun.syndication.io.FeedException;
-import de.congrace.exp4j.Calculable;
-import de.congrace.exp4j.ExpressionBuilder;
+import net.objecthunter.exp4j.Expression;
+import net.objecthunter.exp4j.ExpressionBuilder;
import org.apache.commons.cli.*;
import org.apache.commons.logging.impl.Log4JLogger;
import org.apache.log4j.Level;
@@ -850,8 +850,8 @@ public class Mobibot extends PircBot
try
{
- final Calculable calc = new ExpressionBuilder(args).build();
- send(channel, args.replaceAll(" ", "") + " = " + decimalFormat.format(calc.calculate()));
+ final Expression calc = new ExpressionBuilder(args).build();
+ send(channel, args.replaceAll(" ", "") + " = " + decimalFormat.format(calc.evaluate()));
}
catch (Exception e)
{
@@ -1050,7 +1050,6 @@ public class Mobibot extends PircBot
}
}
-
/**
* Returns indented and bold help string.
*
@@ -1060,7 +1059,7 @@ public class Mobibot extends PircBot
*/
private String helpIndent(String help)
{
- return helpIndent(help, true);
+ return helpIndent(help, true);
}
/**
diff --git a/src/main/java/net/thauvin/erik/mobibot/ReleaseInfo.java b/src/main/java/net/thauvin/erik/mobibot/ReleaseInfo.java
index 1edd473..6179c2b 100644
--- a/src/main/java/net/thauvin/erik/mobibot/ReleaseInfo.java
+++ b/src/main/java/net/thauvin/erik/mobibot/ReleaseInfo.java
@@ -1,5 +1,5 @@
/* Created by JReleaseInfo AntTask from Open Source Competence Group */
-/* Creation date Mon Aug 31 12:19:55 PDT 2015 */
+/* Creation date Mon Oct 26 14:39:18 PDT 2015 */
package net.thauvin.erik.mobibot;
import java.util.Date;
@@ -20,11 +20,11 @@ public class ReleaseInfo {
}
- /** buildDate (set during build process to 1441048795735L). */
- private static final Date buildDate = new Date(1441048795735L);
+ /** buildDate (set during build process to 1445895558361L). */
+ private static final Date buildDate = new Date(1445895558361L);
/**
- * Get buildDate (set during build process to Mon Aug 31 12:19:55 PDT 2015).
+ * Get buildDate (set during build process to Mon Oct 26 14:39:18 PDT 2015).
* @return Date buildDate
*/
public static Date getBuildDate() { return buildDate; }